﻿@"
===============================================================================
Title: 			Netapp Snap notifications.ps1
Description: 	List snapshots over a certain age on all Netapp filers.
Requirements: 	Windows Powershell and the Netapp Powershell Toolkit
Author: 		Ed Grigson 
===============================================================================
"@

Import-module DataOnTap

#Determine which checks to run
$checkSnapshots = $true

#Age of snapshot (in days) before it's included in the report
$WarningDays = 7										
#List the filers you want to scan
$NetappList=("zcgprsan2n1","zcgprsan2n2","zcgprsan1n1","zcgprsan1n2","zbrprsan1n1","zbrprsan1n2","zhc1prsan1n1","zhc1prsan1n2","zhc1prsan2n1","zhc1prsan2n2")
#List of email recipients
#$emailNotifications=("edgr@motabilityoperations.co.uk")	
$emailNotifications=("DL-BusinessSystems-StorageAlerts@motabilityoperations.co.uk")	
#SMTP server
$emailServer="10.1.100.32"

$Now=Get-Date

#This function generates HTML output that uses CSS for style formatting.
$emailContent =		"<html><head><title></title><style type=""text/css"">.Error {color:#FF0000;font-weight: bold;}.Title {background: #0077D4;color: #FFFFFF;text-align:center;font-weight: bold;}.Normal {}</style></head><body>"

if ($checkSnapshots) {
	$emailContent +=	"<p>Please scan the list below for snapshots you've created and remove those which are no longer needed - they're listed by filer with the oldest snapshots at the top. As a general rule a snapshot should not be kept for more than two weeks."
	$emailContent +=	"<p>Only snapshots over $WarningDays days old are shown."
	foreach ($netapp in $NetappList) {	
		$emailContent +=	"<h2>$Netapp</h2>"
		$emailContent +=	"<table><tr class='Title'><td colspan='5'>Netapp Snaphot Report</td></tr><tr class='Title'><td>Parent Volume</td><td>Snapshot Name</td><td width='150px'>Date Created</td><td>Snapshot size</td><td>Snap busy?</td></tr>"
	 	$Report = @()					#Initialise Array for report (an array of objects)
	 	Connect-nacontroller $netapp | select Name,Address
		get-navol | foreach-object {
			$ParentName=$_.Name
			$Snap = get-nasnapshot $ParentName | add-member -membertype noteproperty -name ParentName -value $ParentName -passthru | select ParentName,Name,Total,@{Name="AccessTime";Expression={ConvertTo-DateTime $_.AccessTime}},Busy
			$Report += $Snap
			}
 		Foreach ($snapshot in ($Report | Sort-Object -property AccessTime)){
			#see if the snapshot is older than the value specified in $WarningDays and if so highlight in red
			if ($snapshot.AccessTime -le $Now.AddDays(-$WarningDays)) {
				$snapsize = "{0,20:n3}" -f (($snapshot.Total*1024)/1GB)
				$emailContent +=	"<tr><td>$($snapshot.ParentName)</td><td>$($snapshot.Name)</td><td>$($snapshot.AccessTime)</td><td>$($snapsize)GB</td><td>$($snapshot.Busy)</td></tr> "
			} 
		}
		$emailContent +=	"</table>" 
	}
}

# Generate the report and email it as a HTML body of an email
$SmtpClient = New-Object system.net.mail.smtpClient
$SmtpClient.host = $emailServer  
$MailMessage = New-Object system.net.mail.mailmessage
$MailMessage.from = "snapreport@motabilityoperations.co.uk" #Change to email address you want emails to be coming from
foreach($email in $emailNotifications) {
	$MailMessage.To.add($email)								#Email recipient
}
$MailMessage.Subject = "Netapp Snapshot Report"	
$MailMessage.IsBodyHtml = 1
$MailMessage.Body = $emailContent
$SmtpClient.Send($MailMessage)